@@ -13,7 +13,7 @@ class Application(tornado.web.Application):
         self.miss = 0
         self.put = 0
         super(Application, self).__init__(
-            [("/", MultipleRequestHandler), ("/stats", StatsHandler), ("/(.+)", KeyRequestHandler)],
+            [("/", MultipleRequestHandler), ("/stats", StatsRequestHandler), ("/(.+)", KeyRequestHandler)],
             auto_etag=False)
 
     def log_request(self, handler):
@@ -47,15 +47,18 @@ class KeyRequestHandler(tornado.web.RequestHandler):
 class MultipleRequestHandler(tornado.web.RequestHandler):
     def get(self):
         app = self.application
-        keys = ujson.loads(self.request.body)
-        result = []
-        for key in keys:
-            try:
-                result.append(app.db.Get(key))
-            except KeyError:
-                result.append(None)
+        try:
+            keys = ujson.loads(self.request.body)
+            result = []
+            for key in keys:
+                try:
+                    result.append(app.db.Get(key))
+                except KeyError:
+                    result.append(None)
 
-        self.finish(ujson.dumps(result))
+            self.finish(ujson.dumps(result))
+        except ValueError:
+            raise tornado.web.HTTPError(400)
 
     def put(self):
         app = self.application
@@ -71,7 +74,7 @@ class MultipleRequestHandler(tornado.web.RequestHandler):
         self.finish()
 
 
-class StatsHandler(tornado.web.RequestHandler):
+class StatsRequestHandler(tornado.web.RequestHandler):
     def get(self):
         app = self.application
         self.finish("get: %s, put: %s, miss: %s" % (app.get, app.put, app.miss))
@@ -97,3 +100,7 @@ def run():
         srv.bind(daemon.args.port, daemon.args.interface)
         srv.start()
         tornado.ioloop.IOLoop.instance().start()
+
+
+if "__main__" == __name__:
+    run()
\ No newline at end of file
